@@ -46,7 +46,10 @@ pub struct BrokerReport {
     currency_conversions: Option<CurrencyConversions>,
 
     #[serde(rename = "spot_main_deals_conclusion")]
-    concluded_trades: Option<ConcludedTrades>,
+    concluded_trades: Option<ConcludedTrades<false>>,
+
+    #[serde(rename = "spot_repo_deals_conclusion")]
+    concluded_repo_trades: Option<ConcludedTrades<true>>,
 
     #[serde(rename = "spot_main_deals_executed")]
     executed_trades: Option<ExecutedTrades>,
@@ -96,6 +99,10 @@ impl BrokerReport {
             trades.parse(&mut statement, &securities, &mut trades_with_shifted_execution_date)?;
         }
 
+        if let Some(ref trades) = self.concluded_repo_trades {
+            trades.parse(&mut statement, &securities, &mut HashMap::new())?;
+        }
+
         if let Some(ref cash_flow) = self.cash_flow {
             cash_flow.parse(&mut statement)?;
         }
